@@ -20,9 +20,9 @@ from databuilder.models.column_usage_model import ColumnUsageModel
 from databuilder.models.dashboard.dashboard_chart import DashboardChart
 from databuilder.models.dashboard.dashboard_metadata import DashboardMetadata
 from databuilder.models.dashboard.dashboard_query import DashboardQuery
+from databuilder.models.owner_constants import OWNER_OF_OBJECT_RELATION_TYPE
 from databuilder.models.schema.schema_constant import SCHEMA_REVERSE_RELATION_TYPE
 from databuilder.models.table_metadata import DescriptionMetadata, TableMetadata
-from databuilder.models.table_owner import TableOwner
 from databuilder.models.timestamp.timestamp_constants import LASTUPDATED_RELATION_TYPE, TIMESTAMP_PROPERTY
 from databuilder.models.usage.usage_constants import READ_RELATION_COUNT_PROPERTY, READ_REVERSE_RELATION_TYPE
 from databuilder.models.user import User
@@ -137,7 +137,7 @@ def _user_search_query(graph: GraphTraversalSource, tag_filter: str) -> List[Dic
         __.outE(ColumnUsageModel.USER_TABLE_RELATION_TYPE).values('read_count'),
         __.constant(0)
     ).sum())  # total_read
-    traversal = traversal.by(__.outE(TableOwner.OWNER_TABLE_RELATION_TYPE).fold().count())  # total_own
+    traversal = traversal.by(__.outE(OWNER_OF_OBJECT_RELATION_TYPE).fold().count())  # total_own
     traversal = traversal.by(__.outE('FOLLOWED_BY').fold().count())  # total_follow
     traversal = traversal.order().by(__.select('email'), Order.asc)
     return traversal.toList()
