@@ -3,14 +3,13 @@
 
 import json
 import logging
+from typing import List
 
 from elasticsearch.exceptions import NotFoundError
 from pyhocon import ConfigTree
-from typing import List
-
-from amundsen_common.models.index_map import TABLE_INDEX_MAP as TABLE_ELASTICSEARCH_INDEX_MAPPING
 
 from databuilder.publisher.base_publisher import Publisher
+from databuilder.publisher.elasticsearch_constants import TABLE_ELASTICSEARCH_INDEX_MAPPING
 
 LOGGER = logging.getLogger(__name__)
 
@@ -100,7 +99,7 @@ class ElasticsearchPublisher(Publisher):
             cnt += 1
             if cnt == self.elasticsearch_batch_size:
                 self.elasticsearch_client.bulk(bulk_actions)
-                LOGGER.info('Publish {} of records to ES'.format(str(cnt)))
+                LOGGER.info('Publish %i of records to ES', cnt)
                 cnt = 0
                 bulk_actions = []
 
